package de.intevation.artifactdatabase.rest;

import org.restlet.Component;

import org.restlet.data.Protocol;

import de.intevation.artifacts.ArtifactDatabase;

import de.intevation.artifactdatabase.Config;

import de.intevation.artifactdatabase.rest.RestApp;

import org.apache.log4j.Logger;

public class Standalone
{
    private static Logger logger = Logger.getLogger(Standalone.class);

    public static final String REST_PORT =
        "/artifact-database/rest-server/port/text()";

    public static final int DEFAULT_PORT = 8181;

    public static void startAsServer(ArtifactDatabase db) {
        String portString = Config.getStringXPath(REST_PORT);

        int port = DEFAULT_PORT;

        if (portString != null) {
            try {
                port = Integer.parseInt(portString);
                if (port < 0) {
                    throw new NumberFormatException();
                }
            }
            catch (NumberFormatException nfe) {
                logger.error("rest port is not a positive integer value.", nfe);
                return;
            }
        }

        RestApp app = new RestApp(db);

        Component component = new Component();

        component.getServers().add(Protocol.HTTP, port);

        component.getDefaultHost().attach(app);

        try {
            component.start();
        }
        catch (Exception e) {
            logger.error(e.getLocalizedMessage(), e);
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
